import { HttpErrorResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { MessageService } from './message.service';
/** Type of the handleError function returned by HttpErrorHandler.createHandleError */
export declare type HandleError = <T>(operation?: string, result?: T) => (error: HttpErrorResponse) => Observable<T>;
/** Handles HttpClient errors */
export declare class HttpErrorHandler {
    private messageService;
    constructor(messageService: MessageService);
    /** Create curried handleError function that already knows the service name */
    createHandleError: (serviceName?: string) => <T>(operation?: string, result?: T) => (error: HttpErrorResponse) => Observable<T>;
    /**
     * Returns a function that handles Http operation failures.
     * This error handler lets the app continue to run as if no error occurred.
     * @param serviceName = name of the data service that attempted the operation
     * @param operation - name of the operation that failed
     * @param result - optional value to return as the observable result
     */
    handleError<T>(serviceName?: string, operation?: string, result?: T): (error: HttpErrorResponse) => Observable<T>;
}
